@@ -1,6 +1,6 @@
 #######################################################################
 # seriation - Infrastructure for seriation
-# Copyrigth (C) 2011 Michael Hahsler, Christian Buchta and Kurt Hornik
+# Copyright (C) 2011 Michael Hahsler, Christian Buchta and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 ## calculate path distance from iVAT using a modified version fo Floyd's alg.
 ## d_ij = smallest value of the largest values of all possible paths between i and j
 path_dist <- function(x) {
-
   #A <- as.matrix(x)
   #n <- nrow(A)
   #for(k in 1:n)
@@ -31,26 +30,31 @@ path_dist <- function(x) {
   ## make C call
   m <- as.matrix(x)
 
-  if(any(is.na(m))) stop("NAs not allowed in x.")
-  if(any(m<0)) stop("Negative values not allowed in x.")
+  if (any(is.na(m)))
+    stop("NAs not allowed in x.")
+  if (any(m < 0))
+    stop("Negative values not allowed in x.")
   mode(m) <- "double"
 
   ## replace Inf with large number
   m[is.infinite(m)] <- .Machine$double.xmax
 
-  if(any(m<0)) stop("Negative values not allowed in x.")
+  if (any(m < 0))
+    stop("Negative values not allowed in x.")
 
   m <- .Call("pathdist_floyd", m, PACKAGE = "seriation")
   as.dist(m)
 }
 
-VAT <- function(x, ...) {
-  if(!inherits(x, "dist")) stop("x needs to be of class 'dist'!")
-  pimage(x, seriate(x, "VAT"), ...)
+VAT <- function(x, upper_tri = TRUE, lower_tri = TRUE,...) {
+  if (!inherits(x, "dist"))
+    stop("x needs to be of class 'dist'!")
+  pimage(x, seriate(x, "VAT"), upper_tri = upper_tri, lower_tri = lower_tri,...)
 }
 
-iVAT <- function(x, ...) {
-  if(!inherits(x, "dist")) stop("x needs to be of class 'dist'!")
+iVAT <- function(x, upper_tri = TRUE, lower_tri = TRUE,...) {
+  if (!inherits(x, "dist"))
+    stop("x needs to be of class 'dist'!")
   x <- path_dist(x)
-  pimage(x, seriate(x, "VAT"), ...)
+  pimage(x, seriate(x, "VAT"), upper_tri = upper_tri, lower_tri = lower_tri,...)
 }
